[![package](https://img.shields.io/static/v1?label=install&message=github&color=blue)](https://stereopy.readthedocs.io/en/latest/General/Installation.html) [![documentation](https://img.shields.io/github/stars/BGIResearch/stereopy?logo=GitHub&color=yellow)](https://img.shields.io/github/stars/BGIResearch/stereopy) [![documentation](https://img.shields.io/static/v1?label=docs&message=streopy&color=green)](https://stereopy.readthedocs.io/en/latest/index.html)
## **Stereopy**: Spatial transcriptomics analysis in Python

[Installation](https://stereopy.readthedocs.io/en/latest/General/Installation.html) - [Quick start](https://stereopy.readthedocs.io/en/latest/Tutorials/quick_start.html) - [Documentation](https://stereopy.readthedocs.io/en/latest/index.html) - [API](https://stereopy.readthedocs.io/en/latest/api/index.html)

![Stereopy](https://github.com/BGIResearch/stereopy/blob/main/docs/source/_static/stereopy.PNG)

[comment]: <> (![Stereopy]&#40;./docs/source/_static/stereopy.PNG&#41;)

Stereopy is a tool for data mining and visualization of spatial transcriptomics. It provides a series of analysis of spatial omics, and some tissue image related analysis  will be added later. As the first version may not fully meet the requirements, we will keep on improving it's performance and calculation efficiency, and adding more analyses.

## Discussion 
Please use github issue tracker to report coding related [issues](https://github.com/BGIResearch/stereopy/issues) of stereopy.

## Contribution 
Contributions to stereopy are highly welcome! The contributing guide will be updated later.
